@@ -17,6 +17,10 @@
 #ifndef ZEND_SMART_STR_PUBLIC_H
 #define ZEND_SMART_STR_PUBLIC_H
 
+#include <stddef.h>
+
+typedef struct _zend_string zend_string;
+
 typedef struct {
 	/** See smart_str_extract() */
 	zend_string *s;
