@@ -1,13 +1,11 @@
 /*
-   +----------------------------------------------------------------------+
-   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
    | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
    | available through the world-wide-web at the following url:           |
-   | http://www.php.net/license/3_01.txt                                  |
+   | https://www.php.net/license/3_01.txt                                 |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -25,7 +23,6 @@
 #include "php_mail.h"
 #include "md5.h"
 #include "sha1.h"
-#include "hrtime.h"
 #include "html.h"
 #include "exec.h"
 #include "file.h"
@@ -34,31 +31,21 @@
 #include "php_browscap.h"
 #include "pack.h"
 #include "datetime.h"
-#include "microtime.h"
 #include "url.h"
 #include "pageinfo.h"
-#include "cyr_convert.h"
-#include "php_link.h"
 #include "fsock.h"
 #include "php_image.h"
-#include "php_iptc.h"
 #include "info.h"
-#include "uniqid.h"
 #include "php_var.h"
 #include "quot_print.h"
 #include "dl.h"
 #include "php_crypt.h"
 #include "head.h"
-#include "php_lcg.h"
-#include "php_metaphone.h"
 #include "php_output.h"
 #include "php_array.h"
 #include "php_assert.h"
 #include "php_versioning.h"
-#include "php_ftok.h"
-#include "php_type.h"
 #include "php_password.h"
-#include "php_random.h"
 
 #include "php_version.h"
 #define PHP_STANDARD_VERSION PHP_VERSION
